vfbLib.parsers.glyph.GlyphUnicodeParser
=======================================

.. currentmodule:: vfbLib.parsers.glyph

.. autoclass:: GlyphUnicodeParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GlyphUnicodeParser.__init__
      ~GlyphUnicodeParser.parse
      ~GlyphUnicodeParser.parse_hex
      ~GlyphUnicodeParser.read_double
      ~GlyphUnicodeParser.read_doubles
      ~GlyphUnicodeParser.read_float
      ~GlyphUnicodeParser.read_floats
      ~GlyphUnicodeParser.read_int16
      ~GlyphUnicodeParser.read_int32
      ~GlyphUnicodeParser.read_int8
      ~GlyphUnicodeParser.read_str
      ~GlyphUnicodeParser.read_str_all
      ~GlyphUnicodeParser.read_uint16
      ~GlyphUnicodeParser.read_uint32
      ~GlyphUnicodeParser.read_uint8
      ~GlyphUnicodeParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GlyphUnicodeParser.encoding
      ~GlyphUnicodeParser.master_count
      ~GlyphUnicodeParser.stream
      ~GlyphUnicodeParser.ttStemsH_count
      ~GlyphUnicodeParser.ttStemsV_count
   
   